==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoveryEmailRecoveryToken.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryEmailRecoveryToken
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryEmailRecoveryToken.JSON_PROPERTY_TOKEN_LIFETIME_MINUTES })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyRecoveryEmailRecoveryToken implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TOKEN_LIFETIME_MINUTES = "tokenLifetimeMinutes";
    private Integer tokenLifetimeMinutes = 10080;

    public PasswordPolicyRecoveryEmailRecoveryToken() {
    }

    public PasswordPolicyRecoveryEmailRecoveryToken tokenLifetimeMinutes(Integer tokenLifetimeMinutes) {

        this.tokenLifetimeMinutes = tokenLifetimeMinutes;
        return this;
    }

    /**
     * Lifetime (in minutes) of the recovery token
     *
     * @return tokenLifetimeMinutes
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Lifetime (in minutes) of the recovery token")
    @JsonProperty(JSON_PROPERTY_TOKEN_LIFETIME_MINUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getTokenLifetimeMinutes() {
        return tokenLifetimeMinutes;
    }

    @JsonProperty(JSON_PROPERTY_TOKEN_LIFETIME_MINUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTokenLifetimeMinutes(Integer tokenLifetimeMinutes) {
        this.tokenLifetimeMinutes = tokenLifetimeMinutes;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryEmailRecoveryToken passwordPolicyRecoveryEmailRecoveryToken = (PasswordPolicyRecoveryEmailRecoveryToken) o;
        return Objects.equals(this.tokenLifetimeMinutes, passwordPolicyRecoveryEmailRecoveryToken.tokenLifetimeMinutes);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(tokenLifetimeMinutes);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryEmailRecoveryToken {\n");
        sb.append("    tokenLifetimeMinutes: ").append(toIndentedString(tokenLifetimeMinutes)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PasswordPolicyRecoveryEmailRecoveryToken.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryEmailRecoveryToken
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryEmailRecoveryToken.JSON_PROPERTY_TOKEN_LIFETIME_MINUTES })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyRecoveryEmailRecoveryToken implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_TOKEN_LIFETIME_MINUTES = "tokenLifetimeMinutes";
    private Integer tokenLifetimeMinutes = 10080;

    public PasswordPolicyRecoveryEmailRecoveryToken() {
    }

    public PasswordPolicyRecoveryEmailRecoveryToken tokenLifetimeMinutes(Integer tokenLifetimeMinutes) {

        this.tokenLifetimeMinutes = tokenLifetimeMinutes;
        return this;
    }

    /**
     * Lifetime (in minutes) of the recovery token
     *
     * @return tokenLifetimeMinutes
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Lifetime (in minutes) of the recovery token")
    @JsonProperty(JSON_PROPERTY_TOKEN_LIFETIME_MINUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getTokenLifetimeMinutes() {
        return tokenLifetimeMinutes;
    }

    @JsonProperty(JSON_PROPERTY_TOKEN_LIFETIME_MINUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTokenLifetimeMinutes(Integer tokenLifetimeMinutes) {
        this.tokenLifetimeMinutes = tokenLifetimeMinutes;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryEmailRecoveryToken passwordPolicyRecoveryEmailRecoveryToken = (PasswordPolicyRecoveryEmailRecoveryToken) o;
        return Objects.equals(this.tokenLifetimeMinutes, passwordPolicyRecoveryEmailRecoveryToken.tokenLifetimeMinutes);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(tokenLifetimeMinutes);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryEmailRecoveryToken {\n");
        sb.append("    tokenLifetimeMinutes: ").append(toIndentedString(tokenLifetimeMinutes)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
